### hztrak

A python package which uses stellar parameters to calculate the habitable zone of a stellar system over the course of the star's lifetime.

This code was made by Group 9 (Nick Marston, Basmala Sallam, Skylar Larsen, Natasha Popenoe, Danya Alboslani) during Code/Astro 2025.
